class Iterator(object):

    def __init__(self, client, path, params, response_class, items_key='items',
                 item_mapper=None):
        self.client = client
        self.path = path
        self.params = params
        self.response_class = response_class
        self.items_key = items_key
        self.item_mapper = item_mapper

        self.num_results = 0
        self.page_number = 0
        self._continuation_token = None

    def __iter__(self):
        page_items = self._next_page()
        while page_items:
            self.page_number += 1

            for item in page_items:
                self.num_results += 1
                if self.item_mapper:
                    yield self.item_mapper(item)
                else:
                    yield item

            page_items = self._next_page()

    def _next_page(self):
        if self.page_number == 0 or self._continuation_token:
            params = dict(self.params)

            # 'next' is only allowed to be used by this class
            params.pop('next', None)
            if self._continuation_token is not None:
                params['next'] = self._continuation_token

            response = self.client.get_proto(path=self.path, params=params)
            message = self.response_class()
            message.ParseFromString(response.content)
            items = getattr(message, self.items_key)
            self._continuation_token = getattr(message, 'continuationToken')
            return items
        else:
            return None



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/rest/rest.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.archive import archive_pb2 as yamcs_dot_protobuf_dot_archive_dot_archive__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf.alarms import alarms_pb2 as yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/rest/rest.proto',
  package='yamcs.protobuf.rest',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n\x1eyamcs/protobuf/rest/rest.proto\x12\x13yamcs.protobuf.rest\x1a\x1ayamcs/protobuf/yamcs.proto\x1a$yamcs/protobuf/archive/archive.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\"yamcs/protobuf/alarms/alarms.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\"\xfa\x02\n\x16GetApiOverviewResponse\x12\x14\n\x0cyamcsVersion\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\x10\n\x08serverId\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ultYamcsInstance\x18\x03 \x01(\t\x12\x44\n\x05route\x18\x04 \x03(\x0b\x32\x35.yamcs.protobuf.rest.GetApiOverviewResponse.RouteInfo\x12\x46\n\x06plugin\x18\x05 \x03(\x0b\x32\x36.yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo\x1a(\n\tRouteInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x03(\t\x1aP\n\nPluginInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0e\n\x06vendor\x18\x04 \x01(\t\"m\n\x1c\x42ulkGetParameterValueRequest\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tfromCache\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x04\"U\n\x1d\x42ulkGetParameterValueResponse\x12\x34\n\x05value\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\"\xe8\x01\n\x1c\x42ulkSetParameterValueRequest\x12[\n\x07request\x18\x01 \x03(\x0b\x32J.yamcs.protobuf.rest.BulkSetParameterValueRequest.SetParameterValueRequest\x1ak\n\x18SetParameterValueRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"~\n!BulkDownloadParameterValueRequest\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12)\n\x02id\x18\x03 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tnamespace\x18\x04 \x01(\t\"N\n\x14ListLinkInfoResponse\x12\x36\n\x04link\x18\x01 \x03(\x0b\x32(.yamcs.protobuf.yamcsManagement.LinkInfo\"p\n\x14ListCommandsResponse\x12=\n\x05\x65ntry\x18\x01 \x03(\x0b\x32..yamcs.protobuf.commanding.CommandHistoryEntry\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\" \n\x0f\x45\x64itLinkRequest\x12\r\n\x05state\x18\x01 \x01(\t\"(\n\x17\x45\x64itCommandQueueRequest\x12\r\n\x05state\x18\x01 \x01(\t\"Q\n\x13ListClientsResponse\x12:\n\x06\x63lient\x18\x01 \x03(\x0b\x32*.yamcs.protobuf.yamcsManagement.ClientInfo\"8\n\x11\x45\x64itClientRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"Z\n\x16ListProcessorsResponse\x12@\n\tprocessor\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\"W\n\x19ListCommandQueuesResponse\x12:\n\x05queue\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\"V\n\x17ListCommandQueueEntries\x12;\n\x05\x65ntry\x18\x01 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"-\n\x1c\x45\x64itCommandQueueEntryRequest\x12\r\n\x05state\x18\x01 \x01(\t\"\xd2\x01\n\x13IssueCommandRequest\x12G\n\nassignment\x18\x01 \x03(\x0b\x32\x33.yamcs.protobuf.rest.IssueCommandRequest.Assignment\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x01(\x05\x12\x0e\n\x06\x64ryRun\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x1a)\n\nAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8c\x01\n\x14IssueCommandResponse\x12G\n\x11\x63ommandQueueEntry\x18\x01 \x01(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0b\n\x03hex\x18\x03 \x01(\t\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x0c\"\xcb\x01\n\x1bUpdateCommandHistoryRequest\x12\x33\n\x05\x63mdId\x18\x01 \x02(\x0b\x32$.yamcs.protobuf.commanding.CommandId\x12O\n\x0chistoryEntry\x18\x02 \x03(\x0b\x32\x39.yamcs.protobuf.rest.UpdateCommandHistoryRequest.KeyValue\x1a&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"{\n\x12\x43reateEventRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\t\x12\x0c\n\x04time\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x06 \x01(\x05\"j\n\x16\x43reateProcessorRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x06 \x03(\x05\x12\x12\n\npersistent\x18\x0b \x01(\x08\x12\x0c\n\x04type\x18\x0c \x01(\t\x12\x0e\n\x06\x63onfig\x18\r \x01(\t\"B\n\x14\x45\x64itProcessorRequest\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0c\n\x04seek\x18\x02 \x01(\t\x12\r\n\x05speed\x18\x03 \x01(\t\"(\n\x16StreamSubscribeRequest\x12\x0e\n\x06stream\x18\x01 \x01(\t\"e\n\x18SetSimulationTimeRequest\x12\r\n\x05time0\x18\x01 \x01(\x03\x12\x10\n\x08time0UTC\x18\x02 \x01(\t\x12\x16\n\x0esimElapsedTime\x18\x03 \x01(\x03\x12\x10\n\x08simSpeed\x18\x04 \x01(\x01\"X\n\x15ListInstancesResponse\x12?\n\x08instance\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\xb7\x02\n\x15\x43reateInstanceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12R\n\x0ctemplateArgs\x18\x03 \x03(\x0b\x32<.yamcs.protobuf.rest.CreateInstanceRequest.TemplateArgsEntry\x12\x46\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yamcs.protobuf.rest.CreateInstanceRequest.LabelsEntry\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x1dListInstanceTemplatesResponse\x12\x42\n\x08template\x18\x01 \x03(\x0b\x32\x30.yamcs.protobuf.yamcsManagement.InstanceTemplate\";\n\x10ListTagsResponse\x12\'\n\x03tag\x18\x01 \x03(\x0b\x32\x1a.yamcs.protobuf.ArchiveTag\"a\n\x10\x43reateTagRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0c\n\x04stop\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\"_\n\x0e\x45\x64itTagRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0c\n\x04stop\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\"E\n\x12ListAlarmsResponse\x12/\n\x05\x61larm\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.alarms.AlarmData\"2\n\x10\x45\x64itAlarmRequest\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"F\n\x12ListTablesResponse\x12\x30\n\x05table\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.archive.TableInfo\"I\n\x13ListStreamsResponse\x12\x32\n\x06stream\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.archive.StreamInfo\"U\n\x12ListEventsResponse\x12$\n\x05\x65vent\x18\x01 \x03(\x0b\x32\x15.yamcs.protobuf.Event\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"^\n\x13ListPacketsResponse\x12,\n\x06packet\x18\x01 \x03(\x0b\x32\x1c.yamcs.protobuf.TmPacketData\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"W\n\x17ListServiceInfoResponse\x12<\n\x07service\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.yamcsManagement.ServiceInfo\"r\n\x1bListParameterValuesResponse\x12\x38\n\tparameter\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"#\n\x12\x45\x64itServiceRequest\x12\r\n\x05state\x18\x01 \x01(\t\"V\n\x13\x42ulkGetIndexRequest\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x03(\t\x12\x12\n\npacketname\x18\x04 \x03(\t\"#\n\x13\x43reateBucketRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"<\n\nBucketInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x12\n\nnumObjects\x18\x03 \x01(\r\"\xab\x01\n\nObjectInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12?\n\x08metadata\x18\x04 \x03(\x0b\x32-.yamcs.protobuf.rest.ObjectInfo.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x13ListBucketsResponse\x12/\n\x06\x62ucket\x18\x01 \x03(\x0b\x32\x1f.yamcs.protobuf.rest.BucketInfo\"V\n\x13ListObjectsResponse\x12\x0e\n\x06prefix\x18\x01 \x03(\t\x12/\n\x06object\x18\x02 \x03(\x0b\x32\x1f.yamcs.protobuf.rest.ObjectInfoB\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_archive_dot_archive__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,])




_GETAPIOVERVIEWRESPONSE_ROUTEINFO = _descriptor.Descriptor(
  name='RouteInfo',
  full_name='yamcs.protobuf.rest.GetApiOverviewResponse.RouteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.RouteInfo.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.RouteInfo.method', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=588,
)

_GETAPIOVERVIEWRESPONSE_PLUGININFO = _descriptor.Descriptor(
  name='PluginInfo',
  full_name='yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo.vendor', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=670,
)

_GETAPIOVERVIEWRESPONSE = _descriptor.Descriptor(
  name='GetApiOverviewResponse',
  full_name='yamcs.protobuf.rest.GetApiOverviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsVersion', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.yamcsVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.revision', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.serverId', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultYamcsInstance', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.defaultYamcsInstance', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.route', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='yamcs.protobuf.rest.GetApiOverviewResponse.plugin', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETAPIOVERVIEWRESPONSE_ROUTEINFO, _GETAPIOVERVIEWRESPONSE_PLUGININFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=670,
)


_BULKGETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='BulkGetParameterValueRequest',
  full_name='yamcs.protobuf.rest.BulkGetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.rest.BulkGetParameterValueRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.rest.BulkGetParameterValueRequest.fromCache', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.rest.BulkGetParameterValueRequest.timeout', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=781,
)


_BULKGETPARAMETERVALUERESPONSE = _descriptor.Descriptor(
  name='BulkGetParameterValueResponse',
  full_name='yamcs.protobuf.rest.BulkGetParameterValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.BulkGetParameterValueResponse.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=868,
)


_BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.rest.BulkSetParameterValueRequest.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.rest.BulkSetParameterValueRequest.SetParameterValueRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.BulkSetParameterValueRequest.SetParameterValueRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=996,
  serialized_end=1103,
)

_BULKSETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='BulkSetParameterValueRequest',
  full_name='yamcs.protobuf.rest.BulkSetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.rest.BulkSetParameterValueRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=1103,
)


_BULKDOWNLOADPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='BulkDownloadParameterValueRequest',
  full_name='yamcs.protobuf.rest.BulkDownloadParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.rest.BulkDownloadParameterValueRequest.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.rest.BulkDownloadParameterValueRequest.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.rest.BulkDownloadParameterValueRequest.id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='yamcs.protobuf.rest.BulkDownloadParameterValueRequest.namespace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1231,
)


_LISTLINKINFORESPONSE = _descriptor.Descriptor(
  name='ListLinkInfoResponse',
  full_name='yamcs.protobuf.rest.ListLinkInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='yamcs.protobuf.rest.ListLinkInfoResponse.link', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1311,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.rest.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.rest.ListCommandsResponse.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.rest.ListCommandsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1313,
  serialized_end=1425,
)


_EDITLINKREQUEST = _descriptor.Descriptor(
  name='EditLinkRequest',
  full_name='yamcs.protobuf.rest.EditLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.rest.EditLinkRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1459,
)


_EDITCOMMANDQUEUEREQUEST = _descriptor.Descriptor(
  name='EditCommandQueueRequest',
  full_name='yamcs.protobuf.rest.EditCommandQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.rest.EditCommandQueueRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1461,
  serialized_end=1501,
)


_LISTCLIENTSRESPONSE = _descriptor.Descriptor(
  name='ListClientsResponse',
  full_name='yamcs.protobuf.rest.ListClientsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='yamcs.protobuf.rest.ListClientsResponse.client', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1584,
)


_EDITCLIENTREQUEST = _descriptor.Descriptor(
  name='EditClientRequest',
  full_name='yamcs.protobuf.rest.EditClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.rest.EditClientRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.rest.EditClientRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1642,
)


_LISTPROCESSORSRESPONSE = _descriptor.Descriptor(
  name='ListProcessorsResponse',
  full_name='yamcs.protobuf.rest.ListProcessorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.rest.ListProcessorsResponse.processor', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1734,
)


_LISTCOMMANDQUEUESRESPONSE = _descriptor.Descriptor(
  name='ListCommandQueuesResponse',
  full_name='yamcs.protobuf.rest.ListCommandQueuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.rest.ListCommandQueuesResponse.queue', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1736,
  serialized_end=1823,
)


_LISTCOMMANDQUEUEENTRIES = _descriptor.Descriptor(
  name='ListCommandQueueEntries',
  full_name='yamcs.protobuf.rest.ListCommandQueueEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.rest.ListCommandQueueEntries.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1825,
  serialized_end=1911,
)


_EDITCOMMANDQUEUEENTRYREQUEST = _descriptor.Descriptor(
  name='EditCommandQueueEntryRequest',
  full_name='yamcs.protobuf.rest.EditCommandQueueEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.rest.EditCommandQueueEntryRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1913,
  serialized_end=1958,
)


_ISSUECOMMANDREQUEST_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='yamcs.protobuf.rest.IssueCommandRequest.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.IssueCommandRequest.Assignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.IssueCommandRequest.Assignment.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2130,
  serialized_end=2171,
)

_ISSUECOMMANDREQUEST = _descriptor.Descriptor(
  name='IssueCommandRequest',
  full_name='yamcs.protobuf.rest.IssueCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assignment', full_name='yamcs.protobuf.rest.IssueCommandRequest.assignment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.rest.IssueCommandRequest.origin', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.rest.IssueCommandRequest.sequenceNumber', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='yamcs.protobuf.rest.IssueCommandRequest.dryRun', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.rest.IssueCommandRequest.comment', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDREQUEST_ASSIGNMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1961,
  serialized_end=2171,
)


_ISSUECOMMANDRESPONSE = _descriptor.Descriptor(
  name='IssueCommandResponse',
  full_name='yamcs.protobuf.rest.IssueCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandQueueEntry', full_name='yamcs.protobuf.rest.IssueCommandResponse.commandQueueEntry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.rest.IssueCommandResponse.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hex', full_name='yamcs.protobuf.rest.IssueCommandResponse.hex', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.rest.IssueCommandResponse.binary', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2314,
)


_UPDATECOMMANDHISTORYREQUEST_KEYVALUE = _descriptor.Descriptor(
  name='KeyValue',
  full_name='yamcs.protobuf.rest.UpdateCommandHistoryRequest.KeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.rest.UpdateCommandHistoryRequest.KeyValue.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.UpdateCommandHistoryRequest.KeyValue.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2482,
  serialized_end=2520,
)

_UPDATECOMMANDHISTORYREQUEST = _descriptor.Descriptor(
  name='UpdateCommandHistoryRequest',
  full_name='yamcs.protobuf.rest.UpdateCommandHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmdId', full_name='yamcs.protobuf.rest.UpdateCommandHistoryRequest.cmdId', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='historyEntry', full_name='yamcs.protobuf.rest.UpdateCommandHistoryRequest.historyEntry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECOMMANDHISTORYREQUEST_KEYVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2317,
  serialized_end=2520,
)


_CREATEEVENTREQUEST = _descriptor.Descriptor(
  name='CreateEventRequest',
  full_name='yamcs.protobuf.rest.CreateEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.rest.CreateEventRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.rest.CreateEventRequest.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='yamcs.protobuf.rest.CreateEventRequest.severity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.rest.CreateEventRequest.time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.rest.CreateEventRequest.source', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.rest.CreateEventRequest.sequenceNumber', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2522,
  serialized_end=2645,
)


_CREATEPROCESSORREQUEST = _descriptor.Descriptor(
  name='CreateProcessorRequest',
  full_name='yamcs.protobuf.rest.CreateProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.CreateProcessorRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.rest.CreateProcessorRequest.clientId', index=1,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.rest.CreateProcessorRequest.persistent', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.rest.CreateProcessorRequest.type', index=3,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.rest.CreateProcessorRequest.config', index=4,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2753,
)


_EDITPROCESSORREQUEST = _descriptor.Descriptor(
  name='EditProcessorRequest',
  full_name='yamcs.protobuf.rest.EditProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.rest.EditProcessorRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seek', full_name='yamcs.protobuf.rest.EditProcessorRequest.seek', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.rest.EditProcessorRequest.speed', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2755,
  serialized_end=2821,
)


_STREAMSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='StreamSubscribeRequest',
  full_name='yamcs.protobuf.rest.StreamSubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.rest.StreamSubscribeRequest.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2823,
  serialized_end=2863,
)


_SETSIMULATIONTIMEREQUEST = _descriptor.Descriptor(
  name='SetSimulationTimeRequest',
  full_name='yamcs.protobuf.rest.SetSimulationTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time0', full_name='yamcs.protobuf.rest.SetSimulationTimeRequest.time0', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time0UTC', full_name='yamcs.protobuf.rest.SetSimulationTimeRequest.time0UTC', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simElapsedTime', full_name='yamcs.protobuf.rest.SetSimulationTimeRequest.simElapsedTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simSpeed', full_name='yamcs.protobuf.rest.SetSimulationTimeRequest.simSpeed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2865,
  serialized_end=2966,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yamcs.protobuf.rest.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.rest.ListInstancesResponse.instance', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2968,
  serialized_end=3056,
)


_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.rest.CreateInstanceRequest.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.rest.CreateInstanceRequest.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.CreateInstanceRequest.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3272,
  serialized_end=3323,
)

_CREATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.rest.CreateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.rest.CreateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.CreateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3325,
  serialized_end=3370,
)

_CREATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateInstanceRequest',
  full_name='yamcs.protobuf.rest.CreateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.CreateInstanceRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.rest.CreateInstanceRequest.template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.rest.CreateInstanceRequest.templateArgs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.rest.CreateInstanceRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY, _CREATEINSTANCEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3059,
  serialized_end=3370,
)


_LISTINSTANCETEMPLATESRESPONSE = _descriptor.Descriptor(
  name='ListInstanceTemplatesResponse',
  full_name='yamcs.protobuf.rest.ListInstanceTemplatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.rest.ListInstanceTemplatesResponse.template', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3372,
  serialized_end=3471,
)


_LISTTAGSRESPONSE = _descriptor.Descriptor(
  name='ListTagsResponse',
  full_name='yamcs.protobuf.rest.ListTagsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='yamcs.protobuf.rest.ListTagsResponse.tag', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3473,
  serialized_end=3532,
)


_CREATETAGREQUEST = _descriptor.Descriptor(
  name='CreateTagRequest',
  full_name='yamcs.protobuf.rest.CreateTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.CreateTagRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.rest.CreateTagRequest.start', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.rest.CreateTagRequest.stop', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.rest.CreateTagRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='yamcs.protobuf.rest.CreateTagRequest.color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3534,
  serialized_end=3631,
)


_EDITTAGREQUEST = _descriptor.Descriptor(
  name='EditTagRequest',
  full_name='yamcs.protobuf.rest.EditTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.EditTagRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.rest.EditTagRequest.start', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.rest.EditTagRequest.stop', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.rest.EditTagRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='yamcs.protobuf.rest.EditTagRequest.color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3633,
  serialized_end=3728,
)


_LISTALARMSRESPONSE = _descriptor.Descriptor(
  name='ListAlarmsResponse',
  full_name='yamcs.protobuf.rest.ListAlarmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarm', full_name='yamcs.protobuf.rest.ListAlarmsResponse.alarm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3730,
  serialized_end=3799,
)


_EDITALARMREQUEST = _descriptor.Descriptor(
  name='EditAlarmRequest',
  full_name='yamcs.protobuf.rest.EditAlarmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.rest.EditAlarmRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.rest.EditAlarmRequest.comment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3801,
  serialized_end=3851,
)


_LISTTABLESRESPONSE = _descriptor.Descriptor(
  name='ListTablesResponse',
  full_name='yamcs.protobuf.rest.ListTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='yamcs.protobuf.rest.ListTablesResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3853,
  serialized_end=3923,
)


_LISTSTREAMSRESPONSE = _descriptor.Descriptor(
  name='ListStreamsResponse',
  full_name='yamcs.protobuf.rest.ListStreamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.rest.ListStreamsResponse.stream', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3925,
  serialized_end=3998,
)


_LISTEVENTSRESPONSE = _descriptor.Descriptor(
  name='ListEventsResponse',
  full_name='yamcs.protobuf.rest.ListEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='yamcs.protobuf.rest.ListEventsResponse.event', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.rest.ListEventsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4000,
  serialized_end=4085,
)


_LISTPACKETSRESPONSE = _descriptor.Descriptor(
  name='ListPacketsResponse',
  full_name='yamcs.protobuf.rest.ListPacketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet', full_name='yamcs.protobuf.rest.ListPacketsResponse.packet', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.rest.ListPacketsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4087,
  serialized_end=4181,
)


_LISTSERVICEINFORESPONSE = _descriptor.Descriptor(
  name='ListServiceInfoResponse',
  full_name='yamcs.protobuf.rest.ListServiceInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.rest.ListServiceInfoResponse.service', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4183,
  serialized_end=4270,
)


_LISTPARAMETERVALUESRESPONSE = _descriptor.Descriptor(
  name='ListParameterValuesResponse',
  full_name='yamcs.protobuf.rest.ListParameterValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.rest.ListParameterValuesResponse.parameter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.rest.ListParameterValuesResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4272,
  serialized_end=4386,
)


_EDITSERVICEREQUEST = _descriptor.Descriptor(
  name='EditServiceRequest',
  full_name='yamcs.protobuf.rest.EditServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.rest.EditServiceRequest.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4388,
  serialized_end=4423,
)


_BULKGETINDEXREQUEST = _descriptor.Descriptor(
  name='BulkGetIndexRequest',
  full_name='yamcs.protobuf.rest.BulkGetIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.rest.BulkGetIndexRequest.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.rest.BulkGetIndexRequest.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yamcs.protobuf.rest.BulkGetIndexRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetname', full_name='yamcs.protobuf.rest.BulkGetIndexRequest.packetname', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4425,
  serialized_end=4511,
)


_CREATEBUCKETREQUEST = _descriptor.Descriptor(
  name='CreateBucketRequest',
  full_name='yamcs.protobuf.rest.CreateBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.CreateBucketRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4513,
  serialized_end=4548,
)


_BUCKETINFO = _descriptor.Descriptor(
  name='BucketInfo',
  full_name='yamcs.protobuf.rest.BucketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.BucketInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='yamcs.protobuf.rest.BucketInfo.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numObjects', full_name='yamcs.protobuf.rest.BucketInfo.numObjects', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4550,
  serialized_end=4610,
)


_OBJECTINFO_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yamcs.protobuf.rest.ObjectInfo.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.rest.ObjectInfo.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.rest.ObjectInfo.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4737,
  serialized_end=4784,
)

_OBJECTINFO = _descriptor.Descriptor(
  name='ObjectInfo',
  full_name='yamcs.protobuf.rest.ObjectInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.rest.ObjectInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created', full_name='yamcs.protobuf.rest.ObjectInfo.created', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='yamcs.protobuf.rest.ObjectInfo.size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yamcs.protobuf.rest.ObjectInfo.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTINFO_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4613,
  serialized_end=4784,
)


_LISTBUCKETSRESPONSE = _descriptor.Descriptor(
  name='ListBucketsResponse',
  full_name='yamcs.protobuf.rest.ListBucketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.rest.ListBucketsResponse.bucket', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4786,
  serialized_end=4856,
)


_LISTOBJECTSRESPONSE = _descriptor.Descriptor(
  name='ListObjectsResponse',
  full_name='yamcs.protobuf.rest.ListObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='yamcs.protobuf.rest.ListObjectsResponse.prefix', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='yamcs.protobuf.rest.ListObjectsResponse.object', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4858,
  serialized_end=4944,
)

_GETAPIOVERVIEWRESPONSE_ROUTEINFO.containing_type = _GETAPIOVERVIEWRESPONSE
_GETAPIOVERVIEWRESPONSE_PLUGININFO.containing_type = _GETAPIOVERVIEWRESPONSE
_GETAPIOVERVIEWRESPONSE.fields_by_name['route'].message_type = _GETAPIOVERVIEWRESPONSE_ROUTEINFO
_GETAPIOVERVIEWRESPONSE.fields_by_name['plugin'].message_type = _GETAPIOVERVIEWRESPONSE_PLUGININFO
_BULKGETPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BULKGETPARAMETERVALUERESPONSE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST.containing_type = _BULKSETPARAMETERVALUEREQUEST
_BULKSETPARAMETERVALUEREQUEST.fields_by_name['request'].message_type = _BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST
_BULKDOWNLOADPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_LISTLINKINFORESPONSE.fields_by_name['link'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._LINKINFO
_LISTCOMMANDSRESPONSE.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY
_LISTCLIENTSRESPONSE.fields_by_name['client'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._CLIENTINFO
_LISTPROCESSORSRESPONSE.fields_by_name['processor'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_LISTCOMMANDQUEUESRESPONSE.fields_by_name['queue'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO
_LISTCOMMANDQUEUEENTRIES.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
_ISSUECOMMANDREQUEST_ASSIGNMENT.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST.fields_by_name['assignment'].message_type = _ISSUECOMMANDREQUEST_ASSIGNMENT
_ISSUECOMMANDRESPONSE.fields_by_name['commandQueueEntry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
_UPDATECOMMANDHISTORYREQUEST_KEYVALUE.containing_type = _UPDATECOMMANDHISTORYREQUEST
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['cmdId'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDID
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['historyEntry'].message_type = _UPDATECOMMANDHISTORYREQUEST_KEYVALUE
_LISTINSTANCESRESPONSE.fields_by_name['instance'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._YAMCSINSTANCE
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST.fields_by_name['templateArgs'].message_type = _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY
_CREATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEREQUEST_LABELSENTRY
_LISTINSTANCETEMPLATESRESPONSE.fields_by_name['template'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._INSTANCETEMPLATE
_LISTTAGSRESPONSE.fields_by_name['tag'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._ARCHIVETAG
_LISTALARMSRESPONSE.fields_by_name['alarm'].message_type = yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2._ALARMDATA
_LISTTABLESRESPONSE.fields_by_name['table'].message_type = yamcs_dot_protobuf_dot_archive_dot_archive__pb2._TABLEINFO
_LISTSTREAMSRESPONSE.fields_by_name['stream'].message_type = yamcs_dot_protobuf_dot_archive_dot_archive__pb2._STREAMINFO
_LISTEVENTSRESPONSE.fields_by_name['event'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._EVENT
_LISTPACKETSRESPONSE.fields_by_name['packet'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._TMPACKETDATA
_LISTSERVICEINFORESPONSE.fields_by_name['service'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._SERVICEINFO
_LISTPARAMETERVALUESRESPONSE.fields_by_name['parameter'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_OBJECTINFO_METADATAENTRY.containing_type = _OBJECTINFO
_OBJECTINFO.fields_by_name['metadata'].message_type = _OBJECTINFO_METADATAENTRY
_LISTBUCKETSRESPONSE.fields_by_name['bucket'].message_type = _BUCKETINFO
_LISTOBJECTSRESPONSE.fields_by_name['object'].message_type = _OBJECTINFO
DESCRIPTOR.message_types_by_name['GetApiOverviewResponse'] = _GETAPIOVERVIEWRESPONSE
DESCRIPTOR.message_types_by_name['BulkGetParameterValueRequest'] = _BULKGETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['BulkGetParameterValueResponse'] = _BULKGETPARAMETERVALUERESPONSE
DESCRIPTOR.message_types_by_name['BulkSetParameterValueRequest'] = _BULKSETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['BulkDownloadParameterValueRequest'] = _BULKDOWNLOADPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['ListLinkInfoResponse'] = _LISTLINKINFORESPONSE
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['EditLinkRequest'] = _EDITLINKREQUEST
DESCRIPTOR.message_types_by_name['EditCommandQueueRequest'] = _EDITCOMMANDQUEUEREQUEST
DESCRIPTOR.message_types_by_name['ListClientsResponse'] = _LISTCLIENTSRESPONSE
DESCRIPTOR.message_types_by_name['EditClientRequest'] = _EDITCLIENTREQUEST
DESCRIPTOR.message_types_by_name['ListProcessorsResponse'] = _LISTPROCESSORSRESPONSE
DESCRIPTOR.message_types_by_name['ListCommandQueuesResponse'] = _LISTCOMMANDQUEUESRESPONSE
DESCRIPTOR.message_types_by_name['ListCommandQueueEntries'] = _LISTCOMMANDQUEUEENTRIES
DESCRIPTOR.message_types_by_name['EditCommandQueueEntryRequest'] = _EDITCOMMANDQUEUEENTRYREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandRequest'] = _ISSUECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandResponse'] = _ISSUECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCommandHistoryRequest'] = _UPDATECOMMANDHISTORYREQUEST
DESCRIPTOR.message_types_by_name['CreateEventRequest'] = _CREATEEVENTREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessorRequest'] = _CREATEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['EditProcessorRequest'] = _EDITPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['StreamSubscribeRequest'] = _STREAMSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['SetSimulationTimeRequest'] = _SETSIMULATIONTIMEREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateInstanceRequest'] = _CREATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceTemplatesResponse'] = _LISTINSTANCETEMPLATESRESPONSE
DESCRIPTOR.message_types_by_name['ListTagsResponse'] = _LISTTAGSRESPONSE
DESCRIPTOR.message_types_by_name['CreateTagRequest'] = _CREATETAGREQUEST
DESCRIPTOR.message_types_by_name['EditTagRequest'] = _EDITTAGREQUEST
DESCRIPTOR.message_types_by_name['ListAlarmsResponse'] = _LISTALARMSRESPONSE
DESCRIPTOR.message_types_by_name['EditAlarmRequest'] = _EDITALARMREQUEST
DESCRIPTOR.message_types_by_name['ListTablesResponse'] = _LISTTABLESRESPONSE
DESCRIPTOR.message_types_by_name['ListStreamsResponse'] = _LISTSTREAMSRESPONSE
DESCRIPTOR.message_types_by_name['ListEventsResponse'] = _LISTEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['ListPacketsResponse'] = _LISTPACKETSRESPONSE
DESCRIPTOR.message_types_by_name['ListServiceInfoResponse'] = _LISTSERVICEINFORESPONSE
DESCRIPTOR.message_types_by_name['ListParameterValuesResponse'] = _LISTPARAMETERVALUESRESPONSE
DESCRIPTOR.message_types_by_name['EditServiceRequest'] = _EDITSERVICEREQUEST
DESCRIPTOR.message_types_by_name['BulkGetIndexRequest'] = _BULKGETINDEXREQUEST
DESCRIPTOR.message_types_by_name['CreateBucketRequest'] = _CREATEBUCKETREQUEST
DESCRIPTOR.message_types_by_name['BucketInfo'] = _BUCKETINFO
DESCRIPTOR.message_types_by_name['ObjectInfo'] = _OBJECTINFO
DESCRIPTOR.message_types_by_name['ListBucketsResponse'] = _LISTBUCKETSRESPONSE
DESCRIPTOR.message_types_by_name['ListObjectsResponse'] = _LISTOBJECTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetApiOverviewResponse = _reflection.GeneratedProtocolMessageType('GetApiOverviewResponse', (_message.Message,), dict(

  RouteInfo = _reflection.GeneratedProtocolMessageType('RouteInfo', (_message.Message,), dict(
    DESCRIPTOR = _GETAPIOVERVIEWRESPONSE_ROUTEINFO,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.GetApiOverviewResponse.RouteInfo)
    ))
  ,

  PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), dict(
    DESCRIPTOR = _GETAPIOVERVIEWRESPONSE_PLUGININFO,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.GetApiOverviewResponse.PluginInfo)
    ))
  ,
  DESCRIPTOR = _GETAPIOVERVIEWRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.GetApiOverviewResponse)
  ))
_sym_db.RegisterMessage(GetApiOverviewResponse)
_sym_db.RegisterMessage(GetApiOverviewResponse.RouteInfo)
_sym_db.RegisterMessage(GetApiOverviewResponse.PluginInfo)

BulkGetParameterValueRequest = _reflection.GeneratedProtocolMessageType('BulkGetParameterValueRequest', (_message.Message,), dict(
  DESCRIPTOR = _BULKGETPARAMETERVALUEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BulkGetParameterValueRequest)
  ))
_sym_db.RegisterMessage(BulkGetParameterValueRequest)

BulkGetParameterValueResponse = _reflection.GeneratedProtocolMessageType('BulkGetParameterValueResponse', (_message.Message,), dict(
  DESCRIPTOR = _BULKGETPARAMETERVALUERESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BulkGetParameterValueResponse)
  ))
_sym_db.RegisterMessage(BulkGetParameterValueResponse)

BulkSetParameterValueRequest = _reflection.GeneratedProtocolMessageType('BulkSetParameterValueRequest', (_message.Message,), dict(

  SetParameterValueRequest = _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), dict(
    DESCRIPTOR = _BULKSETPARAMETERVALUEREQUEST_SETPARAMETERVALUEREQUEST,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BulkSetParameterValueRequest.SetParameterValueRequest)
    ))
  ,
  DESCRIPTOR = _BULKSETPARAMETERVALUEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BulkSetParameterValueRequest)
  ))
_sym_db.RegisterMessage(BulkSetParameterValueRequest)
_sym_db.RegisterMessage(BulkSetParameterValueRequest.SetParameterValueRequest)

BulkDownloadParameterValueRequest = _reflection.GeneratedProtocolMessageType('BulkDownloadParameterValueRequest', (_message.Message,), dict(
  DESCRIPTOR = _BULKDOWNLOADPARAMETERVALUEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BulkDownloadParameterValueRequest)
  ))
_sym_db.RegisterMessage(BulkDownloadParameterValueRequest)

ListLinkInfoResponse = _reflection.GeneratedProtocolMessageType('ListLinkInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTLINKINFORESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListLinkInfoResponse)
  ))
_sym_db.RegisterMessage(ListLinkInfoResponse)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCOMMANDSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListCommandsResponse)
  ))
_sym_db.RegisterMessage(ListCommandsResponse)

EditLinkRequest = _reflection.GeneratedProtocolMessageType('EditLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITLINKREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditLinkRequest)
  ))
_sym_db.RegisterMessage(EditLinkRequest)

EditCommandQueueRequest = _reflection.GeneratedProtocolMessageType('EditCommandQueueRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITCOMMANDQUEUEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditCommandQueueRequest)
  ))
_sym_db.RegisterMessage(EditCommandQueueRequest)

ListClientsResponse = _reflection.GeneratedProtocolMessageType('ListClientsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCLIENTSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListClientsResponse)
  ))
_sym_db.RegisterMessage(ListClientsResponse)

EditClientRequest = _reflection.GeneratedProtocolMessageType('EditClientRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITCLIENTREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditClientRequest)
  ))
_sym_db.RegisterMessage(EditClientRequest)

ListProcessorsResponse = _reflection.GeneratedProtocolMessageType('ListProcessorsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPROCESSORSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListProcessorsResponse)
  ))
_sym_db.RegisterMessage(ListProcessorsResponse)

ListCommandQueuesResponse = _reflection.GeneratedProtocolMessageType('ListCommandQueuesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCOMMANDQUEUESRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListCommandQueuesResponse)
  ))
_sym_db.RegisterMessage(ListCommandQueuesResponse)

ListCommandQueueEntries = _reflection.GeneratedProtocolMessageType('ListCommandQueueEntries', (_message.Message,), dict(
  DESCRIPTOR = _LISTCOMMANDQUEUEENTRIES,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListCommandQueueEntries)
  ))
_sym_db.RegisterMessage(ListCommandQueueEntries)

EditCommandQueueEntryRequest = _reflection.GeneratedProtocolMessageType('EditCommandQueueEntryRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITCOMMANDQUEUEENTRYREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditCommandQueueEntryRequest)
  ))
_sym_db.RegisterMessage(EditCommandQueueEntryRequest)

IssueCommandRequest = _reflection.GeneratedProtocolMessageType('IssueCommandRequest', (_message.Message,), dict(

  Assignment = _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), dict(
    DESCRIPTOR = _ISSUECOMMANDREQUEST_ASSIGNMENT,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.IssueCommandRequest.Assignment)
    ))
  ,
  DESCRIPTOR = _ISSUECOMMANDREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.IssueCommandRequest)
  ))
_sym_db.RegisterMessage(IssueCommandRequest)
_sym_db.RegisterMessage(IssueCommandRequest.Assignment)

IssueCommandResponse = _reflection.GeneratedProtocolMessageType('IssueCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _ISSUECOMMANDRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.IssueCommandResponse)
  ))
_sym_db.RegisterMessage(IssueCommandResponse)

UpdateCommandHistoryRequest = _reflection.GeneratedProtocolMessageType('UpdateCommandHistoryRequest', (_message.Message,), dict(

  KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), dict(
    DESCRIPTOR = _UPDATECOMMANDHISTORYREQUEST_KEYVALUE,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.UpdateCommandHistoryRequest.KeyValue)
    ))
  ,
  DESCRIPTOR = _UPDATECOMMANDHISTORYREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.UpdateCommandHistoryRequest)
  ))
_sym_db.RegisterMessage(UpdateCommandHistoryRequest)
_sym_db.RegisterMessage(UpdateCommandHistoryRequest.KeyValue)

CreateEventRequest = _reflection.GeneratedProtocolMessageType('CreateEventRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEEVENTREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateEventRequest)
  ))
_sym_db.RegisterMessage(CreateEventRequest)

CreateProcessorRequest = _reflection.GeneratedProtocolMessageType('CreateProcessorRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEPROCESSORREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateProcessorRequest)
  ))
_sym_db.RegisterMessage(CreateProcessorRequest)

EditProcessorRequest = _reflection.GeneratedProtocolMessageType('EditProcessorRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITPROCESSORREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditProcessorRequest)
  ))
_sym_db.RegisterMessage(EditProcessorRequest)

StreamSubscribeRequest = _reflection.GeneratedProtocolMessageType('StreamSubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _STREAMSUBSCRIBEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.StreamSubscribeRequest)
  ))
_sym_db.RegisterMessage(StreamSubscribeRequest)

SetSimulationTimeRequest = _reflection.GeneratedProtocolMessageType('SetSimulationTimeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSIMULATIONTIMEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.SetSimulationTimeRequest)
  ))
_sym_db.RegisterMessage(SetSimulationTimeRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTINSTANCESRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListInstancesResponse)
  ))
_sym_db.RegisterMessage(ListInstancesResponse)

CreateInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceRequest', (_message.Message,), dict(

  TemplateArgsEntry = _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateInstanceRequest.TemplateArgsEntry)
    ))
  ,

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CREATEINSTANCEREQUEST_LABELSENTRY,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateInstanceRequest.LabelsEntry)
    ))
  ,
  DESCRIPTOR = _CREATEINSTANCEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateInstanceRequest)
  ))
_sym_db.RegisterMessage(CreateInstanceRequest)
_sym_db.RegisterMessage(CreateInstanceRequest.TemplateArgsEntry)
_sym_db.RegisterMessage(CreateInstanceRequest.LabelsEntry)

ListInstanceTemplatesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceTemplatesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTINSTANCETEMPLATESRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListInstanceTemplatesResponse)
  ))
_sym_db.RegisterMessage(ListInstanceTemplatesResponse)

ListTagsResponse = _reflection.GeneratedProtocolMessageType('ListTagsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTTAGSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListTagsResponse)
  ))
_sym_db.RegisterMessage(ListTagsResponse)

CreateTagRequest = _reflection.GeneratedProtocolMessageType('CreateTagRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATETAGREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateTagRequest)
  ))
_sym_db.RegisterMessage(CreateTagRequest)

EditTagRequest = _reflection.GeneratedProtocolMessageType('EditTagRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITTAGREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditTagRequest)
  ))
_sym_db.RegisterMessage(EditTagRequest)

ListAlarmsResponse = _reflection.GeneratedProtocolMessageType('ListAlarmsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTALARMSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListAlarmsResponse)
  ))
_sym_db.RegisterMessage(ListAlarmsResponse)

EditAlarmRequest = _reflection.GeneratedProtocolMessageType('EditAlarmRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITALARMREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditAlarmRequest)
  ))
_sym_db.RegisterMessage(EditAlarmRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTTABLESRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListTablesResponse)
  ))
_sym_db.RegisterMessage(ListTablesResponse)

ListStreamsResponse = _reflection.GeneratedProtocolMessageType('ListStreamsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTSTREAMSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListStreamsResponse)
  ))
_sym_db.RegisterMessage(ListStreamsResponse)

ListEventsResponse = _reflection.GeneratedProtocolMessageType('ListEventsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTEVENTSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListEventsResponse)
  ))
_sym_db.RegisterMessage(ListEventsResponse)

ListPacketsResponse = _reflection.GeneratedProtocolMessageType('ListPacketsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPACKETSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListPacketsResponse)
  ))
_sym_db.RegisterMessage(ListPacketsResponse)

ListServiceInfoResponse = _reflection.GeneratedProtocolMessageType('ListServiceInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTSERVICEINFORESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListServiceInfoResponse)
  ))
_sym_db.RegisterMessage(ListServiceInfoResponse)

ListParameterValuesResponse = _reflection.GeneratedProtocolMessageType('ListParameterValuesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPARAMETERVALUESRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListParameterValuesResponse)
  ))
_sym_db.RegisterMessage(ListParameterValuesResponse)

EditServiceRequest = _reflection.GeneratedProtocolMessageType('EditServiceRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITSERVICEREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.EditServiceRequest)
  ))
_sym_db.RegisterMessage(EditServiceRequest)

BulkGetIndexRequest = _reflection.GeneratedProtocolMessageType('BulkGetIndexRequest', (_message.Message,), dict(
  DESCRIPTOR = _BULKGETINDEXREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BulkGetIndexRequest)
  ))
_sym_db.RegisterMessage(BulkGetIndexRequest)

CreateBucketRequest = _reflection.GeneratedProtocolMessageType('CreateBucketRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEBUCKETREQUEST,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.CreateBucketRequest)
  ))
_sym_db.RegisterMessage(CreateBucketRequest)

BucketInfo = _reflection.GeneratedProtocolMessageType('BucketInfo', (_message.Message,), dict(
  DESCRIPTOR = _BUCKETINFO,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.BucketInfo)
  ))
_sym_db.RegisterMessage(BucketInfo)

ObjectInfo = _reflection.GeneratedProtocolMessageType('ObjectInfo', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _OBJECTINFO_METADATAENTRY,
    __module__ = 'yamcs.protobuf.rest.rest_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ObjectInfo.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _OBJECTINFO,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ObjectInfo)
  ))
_sym_db.RegisterMessage(ObjectInfo)
_sym_db.RegisterMessage(ObjectInfo.MetadataEntry)

ListBucketsResponse = _reflection.GeneratedProtocolMessageType('ListBucketsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTBUCKETSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListBucketsResponse)
  ))
_sym_db.RegisterMessage(ListBucketsResponse)

ListObjectsResponse = _reflection.GeneratedProtocolMessageType('ListObjectsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTOBJECTSRESPONSE,
  __module__ = 'yamcs.protobuf.rest.rest_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.rest.ListObjectsResponse)
  ))
_sym_db.RegisterMessage(ListObjectsResponse)


DESCRIPTOR._options = None
_CREATEINSTANCEREQUEST_TEMPLATEARGSENTRY._options = None
_CREATEINSTANCEREQUEST_LABELSENTRY._options = None
_OBJECTINFO_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)
